@@ -1051,6 +1051,11 @@ set_cellstyles <- function(wb, style) {
 
     xf_xml <- write_xf(xf_df) # can be NULL
 
+    if (length(xf_xml) == 0) {
+      # TODO: why was this NULL in the first place? dxf?
+      xf_xml <- wb$styles_mgr$styles$cellXfs[[1]]
+    }
+
     if (length(xf_xml))
       wb$styles_mgr$add(xf_xml, session_id)
   }
@@ -1323,9 +1328,8 @@ fits_in_dims <- function(x, dims, startCol, startRow) {
 
   }
 
-  rc <- dims_to_rowcol(dims)
-  if (max(as.integer(rc[["row"]])) > 1048576 || max(col2int(rc[["col"]])) > 16384)
-    stop("Dimensions exceed worksheet")
+  # final check if any column or row exceeds the valid ranges
+  validate_dims(dims)
 
   dims
 }
