@@ -36,19 +36,19 @@ border_sty <- "thin"
 dims_mat_header <- wb_dims(rows = 1, cols = seq_len(ncol(mat)))
 # returns "A1:AB1"
 # prepare workbook with data and formated first row
-wb <- wb_workbook() %>%
-  wb_add_worksheet("test") %>%
-  wb_add_data(x = mat) %>%
-  wb_add_border(dims = dims_mat_header,
+wb <- wb_workbook()$
+  add_worksheet("test")$
+  add_data(x = mat)$
+  add_border(dims = dims_mat_header,
     top_color = border_col, top_border = border_sty,
     bottom_color = border_col, bottom_border = border_sty,
     left_color = border_col, left_border = border_sty,
     right_color = border_col, right_border = border_sty,
     inner_hcolor = border_col, inner_hgrid = border_sty
-  ) %>%
-  wb_add_fill(dims = dims_mat_header, color = wb_color(hex = "FF334E6F")) %>%
-  wb_add_font(dims = dims_mat_header, name = "Arial", bold = TRUE, color = wb_color("white"), size = 20) %>%
-  wb_add_cell_style(dims = dims_mat_header, horizontal = "center", textRotation = 45)
+  )$
+  add_fill(dims = dims_mat_header, color = wb_color(hex = "FF334E6F"))$
+  add_font(dims = dims_mat_header, name = "Arial", bold = TRUE, color = wb_color("white"), size = 20)$
+  add_cell_style(dims = dims_mat_header, horizontal = "center", textRotation = 45)
 
 # create various number formats
 x <- c(
@@ -59,14 +59,14 @@ x <- c(
 # apply the styles
 for (i in seq_along(x)) {
   cell <- sprintf("%s2:%s29", int2col(i), int2col(i))
-  wb <- wb %>% wb_add_numfmt(dims = cell, numfmt = x[i])
+  wb$add_numfmt(dims = cell, numfmt = x[i])
 }
 
 # wb$open()
 
 ## -----------------------------------------------------------------------------
 # create workbook
-wb <- wb_workbook() %>% wb_add_worksheet("test")
+wb <- wb_workbook()$add_worksheet("test")
 
 # add some dummy data to the worksheet
 set.seed(123)
@@ -111,7 +111,7 @@ wb$styles_mgr$add(new_cellxfs, "new_styles")
 # Achieve the same with `wb_dims()` and sprintf
 # cell <- sprintf("A1:%s1", int2col(nrow(mat)))
 cell <- wb_dims(rows = 1, cols = seq_len(ncol(mat)))
-wb <- wb %>% wb_set_cell_style(
+wb$set_cell_style(
   dims = cell,
   style = wb$styles_mgr$get_xf_id("new_styles")
 )
@@ -135,7 +135,7 @@ for (i in seq_along(x)) {
 new_styles <- wb$styles_mgr$get_xf()
 for (i in as.integer(new_styles$id[new_styles$name %in% paste0("new_style", seq_along(x))])) {
   cell <- wb_dims(rows = seq_len(nrow(mat)), cols = i, from_row = 2)
-  wb <- wb %>% wb_set_cell_style(dims = cell, style = i)
+  wb$set_cell_style(dims = cell, style = i)
 }
 
 # assign a custom tabColor
@@ -167,7 +167,7 @@ df <- data.frame(
   "TinyNumbers" = runif(20) / 1E9, stringsAsFactors = FALSE
 )
 
-## openxlsx will apply default Excel styling for these classes
+## openxlsx will apply default spreadsheet styling for these classes
 class(df$Cash) <- c(class(df$Cash), "currency")
 class(df$Cash2) <- c(class(df$Cash2), "accounting")
 class(df$hLink) <- "hyperlink"
@@ -178,8 +178,7 @@ wb$add_data("S1", x = df, start_row = 4, row_names = FALSE)
 wb$add_data_table("S2", x = df, start_row = 4, row_names = FALSE)
 
 ## -----------------------------------------------------------------------------
-wb <- wb_workbook()
-wb <- wb_add_worksheet(wb, "test")
+wb <- wb_workbook()$add_worksheet("test")
 
 options("openxlsx2.dateFormat" = "yyyy")
 options("openxlsx2.datetimeFormat" = "yyyy-mm-dd")
@@ -196,7 +195,7 @@ df <- data.frame(
   "numeric" = 1
 )
 
-## openxlsx will apply default Excel styling for these classes
+## openxlsx will apply default spreadsheet styling for these classes
 class(df$Cash) <- c(class(df$Cash), "currency")
 class(df$Cash2) <- c(class(df$Cash2), "accounting")
 class(df$hLink) <- "hyperlink"
@@ -210,44 +209,44 @@ wb$add_data("test", df)
 options("openxlsx2.numFmt" = NULL)
 
 ## -----------------------------------------------------------------------------
-wb <- wb_workbook() %>%
-  wb_add_worksheet() %>%
-  wb_add_data(x = mtcars, row_names = TRUE)
+wb <- wb_workbook()$
+  add_worksheet()$
+  add_data(x = mtcars, row_names = TRUE)
 
 cols <- 1:12
-wb <- wb %>% wb_set_col_widths(cols = cols, widths = "auto")
+wb$set_col_widths(cols = cols, widths = "auto")
 
 ## -----------------------------------------------------------------------------
-wb <- wb_workbook()
+wb <- wb_workbook()$
 # full inner grid
-  wb$add_worksheet(sheet = "S1", grid_lines = FALSE)$
-  add_data(x = mtcars)
-wb$add_border(
-  dims = "A2:K33", # can use wb_dims(rows = 2:33, cols = ncol(mtcars))
-  inner_hgrid = "thin",
-  inner_hcolor = wb_color(hex = "FF808080"),
-  inner_vgrid = "thin",
-  inner_vcolor = wb_color(hex = "FF808080")
-)
+  add_worksheet(sheet = "S1", grid_lines = FALSE)$
+  add_data(x = mtcars)$
+  add_border(
+    dims = "A2:K33", # can use wb_dims(rows = 2:33, cols = ncol(mtcars))
+    inner_hgrid = "thin",
+    inner_hcolor = wb_color(hex = "FF808080"),
+    inner_vgrid = "thin",
+    inner_vcolor = wb_color(hex = "FF808080")
+  )$
 # only horizontal grid
-wb$add_worksheet("S2", grid_lines = FALSE)$
-  add_data(x = mtcars)
-wb$add_border(
+  add_worksheet("S2", grid_lines = FALSE)$
+  add_data(x = mtcars)$
+  add_border(
   dims = "A2:K33",
   inner_hgrid = "thin",
   inner_hcolor = wb_color(hex = "FF808080")
-  )
+  )$
 # only vertical grid
-wb$add_worksheet("S3", grid_lines = FALSE)$
-  add_data(x = mtcars)
-wb$add_border(
+  add_worksheet("S3", grid_lines = FALSE)$
+  add_data(x = mtcars)$
+  add_border(
   dims = "A2:K33",
   inner_vgrid = "thin",
   inner_vcolor = wb_color(hex = "FF808080")
-  )
+  )$
 # no inner grid
-wb$add_worksheet("S4", grid_lines = FALSE)$add_data(x = mtcars)
-wb$add_border("S4", dims = "A2:K33")
+  add_worksheet("S4", grid_lines = FALSE)$add_data(x = mtcars)$
+  add_border("S4", dims = "A2:K33")
 # wb_open(wb)
 
 ## ----echo=FALSE, warning=FALSE, fig.cap="Tiny table with minimal styling"-----
@@ -258,20 +257,20 @@ knitr::include_graphics("img/styled_table.jpg")
 mat <- matrix(1:4, ncol = 2, nrow = 2)
 colnames(mat) <- make.names(seq_len(ncol(mat)))
 
-wb <- wb_workbook() %>%
-  wb_add_worksheet("test") %>%
-  wb_add_data(x = mat, dims = wb_dims(from_dims = "B2")) %>%
+wb <- wb_workbook()$
+  add_worksheet("test")$
+  add_data(x = mat, dims = wb_dims(from_dims = "B2"))$
   # center first row
-  wb_add_cell_style(dims = "B2:C2", horizontal = "center") %>%
+  add_cell_style(dims = "B2:C2", horizontal = "center")$
   # add border for first row
-  wb_add_border(
+  add_border(
     dims = "B2:C2",
     bottom_color = wb_color(theme = 1), bottom_border = "thin",
     top_color = wb_color(theme = 1), top_border = "double",
     left_border = NULL, right_border = NULL
-  ) %>%
+  )$
   # add border for last row
-  wb_add_border(
+  add_border(
     dims = "B4:C4",
     bottom_color = wb_color(theme = 1), bottom_border = "double",
     top_border = NULL, left_border = NULL, right_border = NULL
@@ -282,9 +281,9 @@ wb <- wb_workbook() %>%
 mat <- matrix(1:4, ncol = 2, nrow = 2)
 colnames(mat) <- make.names(seq_len(ncol(mat)))
 
-wb <- wb_workbook() %>%
-  wb_add_worksheet("test") %>%
-  wb_add_data(
+wb <- wb_workbook()$
+  add_worksheet("test")$
+  add_data(
     x = mat,
     dims = wb_dims(2, 2)
   )
@@ -318,15 +317,15 @@ wb$styles_mgr$add(bottom_cellxfs, "bottom_styles")
 
 # assign the new cell style to the header row of our data set
 cell <- "B2:C2"
-wb <- wb %>% wb_set_cell_style(dims = cell, style = wb$styles_mgr$get_xf_id("top_styles"))
+wb$set_cell_style(dims = cell, style = wb$styles_mgr$get_xf_id("top_styles"))
 cell <- "B4:C4"
-wb <- wb %>% wb_set_cell_style(dims = cell, style = wb$styles_mgr$get_xf_id("bottom_styles"))
+wb$set_cell_style(dims = cell, style = wb$styles_mgr$get_xf_id("bottom_styles"))
 
 ## ----echo=FALSE, warning=FALSE, out.width="100%", fig.cap="Tint variations of the theme colors."----
 knitr::include_graphics("img/color_tint.jpg")
 
 ## -----------------------------------------------------------------------------
-wb <- wb_workbook() %>% wb_add_worksheet("S1")
+wb <- wb_workbook()$add_worksheet("S1")
 
 tints <- seq(-0.9, 0.9, by = 0.1)
 
@@ -335,16 +334,17 @@ for (i in 0:9) {
     col <- paste0(int2col(i + 1), which(tints %in% tnt))
 
     if (tnt == 0) {
-      wb <- wb %>% wb_add_fill(dims = col, color = wb_color(theme = i))
+      wb$add_fill(dims = col, color = wb_color(theme = i))
     } else {
-      wb <- wb %>% wb_add_fill(dims = col, color = wb_color(theme = i, tint = tnt))
+      wb$add_fill(dims = col, color = wb_color(theme = i, tint = tnt))
     }
   }
 }
 
 ## -----------------------------------------------------------------------------
-wb <- wb_load(system.file("extdata", "oxlsx2_sheet.xlsx", package = "openxlsx2")) %>%
-  wb_set_cell_style(1, "A30:G35", wb_get_cell_style(., 1, "A10:G15"))
+wb <- wb_load(system.file("extdata", "oxlsx2_sheet.xlsx", package = "openxlsx2"))
+
+wb$set_cell_style(1, "A30:G35", wb$get_cell_style(1, "A10:G15"))
 # wb_open(wb)
 
 ## -----------------------------------------------------------------------------
@@ -363,7 +363,7 @@ df[df < 4] <- NA
 
 na_red <- fmt_txt("N/A", color = wb_color("red"), italic = TRUE, bold = TRUE)
 
-wb <- wb_workbook()$add_worksheet()$add_data(x = df, na.strings = na_red)
+wb <- wb_workbook()$add_worksheet()$add_data(x = df, na = na_red)
 
 ## -----------------------------------------------------------------------------
 # a red table style
@@ -433,8 +433,8 @@ dx8 <- create_dxfs_style(
 )
 
 
-wb <- wb_workbook() %>%
-  wb_add_worksheet(grid_lines = FALSE)
+wb <- wb_workbook()$
+  add_worksheet(grid_lines = FALSE)
 
 wb$add_style(dx0)
 wb$add_style(dx1)
@@ -464,6 +464,5 @@ xml <- create_tablestyle(
 wb$add_style(xml)
 
 # create a table and apply the custom style
-wb <- wb %>%
-  wb_add_data_table(x = mtcars, table_style = "red_table")
+wb$add_data_table(x = mtcars, table_style = "red_table")
 
