@@ -2,282 +2,6 @@
 #define XLSB_DEFINES_H
 
 // defines
-typedef struct {
-  bool fBuiltIn : 1;
-  bool fHidden : 1;
-  bool fCustom : 1;
-  uint16_t unused : 13;
-} StyleFlagsFields;
-
-typedef struct {
-  bool bit1 : 1;
-  bool bit2 : 1;
-  bool bit3 : 1;
-  bool bit4 : 1;
-  bool bit5 : 1;
-  bool bit6 : 1;
-} xfGrbitAtrFields;
-
-typedef struct {
-  bool reserved : 1;
-  bool fAlwaysCalc : 1;
-  uint16_t unused : 14;
-} GrbitFmlaFields;
-
-typedef struct {
-  uint16_t col : 14;
-  bool fColRel : 1;
-  bool fRwRel : 1;
-} ColRelShortFields;
-
-typedef struct {
-  bool fExtraAsc : 1;
-  bool fExtraDsc : 1;
-  uint8_t reserved1 : 6;
-  uint8_t iOutLevel : 3;
-  bool fCollapsed : 1;
-  bool fDyZero : 1;
-  bool fUnsynced : 1;
-  bool fGhostDirty : 1;
-  bool fReserved : 1;
-} BrtRowHdrFields;
-
-typedef struct {
-  bool fHidden : 1;
-  bool fUserSet : 1;
-  bool fBestFit : 1;
-  bool fPhonetic : 1;
-  uint8_t reserved1 : 4;
-  uint8_t iOutLevel : 3;
-  bool unused : 1;
-  bool fCollapsed : 1;
-  uint8_t reserved2 : 3;
-} BrtColInfoFields;
-
-typedef struct {
-  bool fHidden : 1;
-  bool fFunc : 1;
-  bool fOB : 1;
-  bool fProc : 1;
-  bool fCalcExp : 1;
-  bool fBuiltin : 1;
-  uint16_t fgrp : 9;
-  bool fPublished : 1;
-} BrtNameFields;
-
-typedef struct {
-  bool fWorkbookParam : 1;
-  bool fFutureFunction : 1;
-  uint16_t reserved : 14;
-} BrtNameFields2;
-
-typedef struct {
-  bool unused1 : 1;
-  bool fItalic : 1;
-  bool unused2 : 1;
-  bool fStrikeout : 1;
-  bool fOutline : 1;
-  bool fShadow : 1;
-  bool fCondense : 1;
-  bool fExtend : 1;
-  uint8_t unused3 : 8;
-} FontFlagsFields;
-
-typedef struct {
-  uint8_t alc : 3;
-  uint8_t alcv : 3;
-  bool fWrap : 1;
-  bool fJustLast : 1;
-  bool fShrinkToFit : 1;
-  bool fMergeCell : 1;
-  uint8_t iReadingOrder : 2;
-  bool fLocked : 1;
-  bool fHidden : 1;
-  bool fSxButton : 1;
-  bool f123Prefix : 1;
-  uint8_t xfGrbitAtr : 6;
-  uint16_t unused : 10;
-} XFFields;
-
-typedef struct {
-  bool fShowAutoBreaks : 1;
-  uint8_t rserved1 : 2;
-  bool fPublish : 1;
-  bool fDialog : 1;
-  bool fApplyStyles : 1;
-  bool fRowSumsBelow : 1;
-  bool fColSumsRight : 1;
-  bool fFitToPage : 1;
-  uint8_t reserved2 : 1;
-  bool fShowOutlineSymbols : 1;
-  uint8_t reserved3 : 1;
-  bool fSyncHoriz : 1;
-  bool fSyncVert : 1;
-  bool fAltExprEval : 1;
-  bool fAltFormulaEntry : 1;
-} BrtWsPropFields1;
-
-typedef struct {
-  bool fFilterMode : 1;
-  bool fCondFmtCalc : 1;
-  uint8_t reserved4 : 6;
-} BrtWsPropFields2;
-
-typedef struct {
-  bool fWnProt : 1;
-  bool fDspFmla : 1;
-  bool fDspGrid : 1;
-  bool fDspRwCol : 1;
-  bool fDspZeros : 1;
-  bool fRightToLeft : 1;
-  bool fSelected : 1;
-  bool fDspRuler : 1;
-  bool fDspGuts : 1;
-  bool fDefaultHdr : 1;
-  bool fWhitespaceHidden : 1;
-  uint8_t reserved1 : 5;
-} BrtBeginWsViewFields;
-
-typedef struct {
-  bool fFirstColumn : 1;
-  bool fLastColumn : 1;
-  bool fRowStripes : 1;
-  bool fColumnStripes : 1;
-  bool fRowHeaders : 1;
-  bool fColumnHeaders : 1;
-  uint16_t reserved : 10;
-} BrtTableStyleClientFields;
-
-typedef struct {
-  bool reserved3 : 1;
-  bool fStopTrue : 1;
-  bool fAbove : 1;
-  bool fBottom : 1;
-  bool fPercent : 1;
-  uint16_t reserved4 : 11;
-} BrtBeginCFRuleFields;
-
-typedef struct {
-  bool f1904 : 1;
-  bool reserved1 : 1;
-  bool fHideBorderUnselLists : 1;
-  bool fFilterPrivacy : 1;
-  bool fBuggedUserAboutSolution : 1;
-  bool fShowInkAnnotation : 1;
-  bool fBackup : 1;
-  bool fNoSaveSup : 1;
-  uint8_t grbitUpdateLinks : 2;
-  bool fHidePivotTableFList : 1;
-  bool fPublishedBookItems : 1;
-  bool fCheckCompat : 1;
-  uint8_t mdDspObj : 2;
-  bool fShowPivotChartFilter : 1;
-  bool fAutoCompressPictures : 1;
-  bool reserved2 : 1;
-  bool fRefreshAll : 1;
-  uint16_t unused : 13;
-} BrtWbPropFields;
-
-typedef struct {
-  uint8_t valType : 4;
-  uint8_t errStyle : 3;
-  bool unused : 1;
-  bool fAllowBlank : 1;
-  bool fSuppressCombo : 1;
-  uint8_t mdImeMode : 8;
-  bool fShowInputMsg : 1;
-  bool fShowErrorMsg : 1;
-  uint8_t typOperator : 4;
-  bool fDVMinFmla : 1;  // only in 14
-  bool fDVMaxFmla : 1;  // only in 14
-  uint8_t reserved : 6;
-} BrtDValFields;
-
-typedef struct {
-  uint16_t product : 15;
-  bool reserved : 1;
-} FRTVersionFields;
-
-typedef struct {
-  bool fRef : 1;
-  bool fSqref : 1;
-  bool fFormula : 1;
-  bool fRelID : 1;
-  uint32_t reserved : 28;
-} FRTHeaderFields;
-
-typedef struct {
-  uint8_t columns : 2;
-  uint8_t rowType : 5;
-  bool squareBracketSpace : 1;
-  bool commaSpace : 1;
-  bool unused : 1;
-  uint8_t type : 2;
-  bool invalid : 1;
-  bool nonresident : 1;
-  uint8_t reserved2 : 2;
-} PtgListFields;
-
-typedef struct {
-  bool fShowBrks : 1;
-  bool fDspFmlaSv : 1;
-  bool fDspGridSv : 1;
-  bool fDspRwColSv : 1;
-  bool fDspGutsSv : 1;
-  bool fDspZerosSv : 1;
-  bool fHorizontal : 1;
-  bool fVertical : 1;
-  bool fPrintRwCol : 1;
-  bool fPrintGrid : 1;
-  bool fFitToPage : 1;
-  bool fPrintArea : 1;
-  bool fOnePrintArea : 1;
-  bool fFilterMode : 1;
-  bool fEzFilter : 1;
-  bool reserved1 : 1;
-  bool reserved2 : 1;
-  bool fSplitV : 1;
-  bool fSplitH : 1;
-  uint8_t fHiddenRw : 2;
-  bool fHiddenCol : 1;
-  uint8_t hsState : 2;
-  bool reserved3 : 1;
-  bool fFilterUnique : 1;
-  bool fSheetLayoutView : 1;
-  bool fPageLayoutView : 1;
-  bool reserved4 : 1;
-  bool fRuler : 1;
-  bool reserved5 : 1;
-  bool reserved6 : 1;
-} BrtBeginUserShViewFields;
-
-typedef struct {
-  bool fIconic : 1;
-  bool fDspHScroll : 1;
-  bool fDspVScroll : 1;
-  bool fBotAdornment : 1;
-  bool fZoom : 1;
-  bool fDspFmlaBar : 1;
-  bool fDspStatus : 1;
-  uint8_t mdDspNote : 2;
-  uint8_t mdHideObj : 2;
-  bool fPrintIncl : 1;
-  bool fRowColIncl : 1;
-  bool fTimedUpdate : 1;
-  bool fAllMemChanges : 1;
-  bool fOnlySync : 1;
-  bool fPersonalView : 1;
-  uint16_t : 15;
-} BrtUserBookViewFields;
-
-typedef struct {
-  bool fHFDiffOddEven : 1;
-  bool fHFDiffFirst : 1;
-  bool fHFScaleWithDoc : 1;
-  bool fHFAlignMargins : 1;
-  uint16_t reserved : 12;
-} BrtBeginHeaderFooterFields;
-
 enum PtgRowType {
   data = 0x00,
   all = 0x01,      // #All
