@@ -34,7 +34,6 @@ test_that("wb_set_col_widths works", {
   expect_silent(wb$set_col_widths("test", cols = "Y", widths = 22))
   expect_equal(
     c("<col min=\"1\" max=\"11\" bestFit=\"1\" customWidth=\"1\" hidden=\"false\" width=\"9.141\"/>",
-      "<col min=\"12\" max=\"24\" width=\"8.43\"/>",
       "<col min=\"25\" max=\"25\" bestFit=\"1\" customWidth=\"1\" hidden=\"false\" width=\"22.711\"/>"),
     wb$worksheets[[1]]$cols_attr
   )
@@ -87,8 +86,8 @@ test_that("merged cells are excluded from col width `auto` calculation", {
     set_col_widths(cols = "A:B", width = "auto")
 
   exp <- c(
-    "<col min=\"1\" max=\"1\" bestFit=\"1\" customWidth=\"1\" hidden=\"false\" width=\"6.711\"/>",
-    "<col min=\"2\" max=\"2\" bestFit=\"1\" customWidth=\"1\" hidden=\"false\" width=\"5.711\"/>"
+    "<col min=\"1\" max=\"1\" bestFit=\"1\" customWidth=\"1\" hidden=\"false\" width=\"5.711\"/>",
+    "<col min=\"2\" max=\"2\" bestFit=\"1\" customWidth=\"1\" hidden=\"false\" width=\"4.711\"/>"
   )
   got <- wb$worksheets[[1]]$cols_attr
   expect_equal(exp, got)
@@ -167,6 +166,7 @@ test_that("$set_sheet_names() and $get_sheet_names() work", {
 test_that("data validation", {
 
   temp <- temp_xlsx()
+  on.exit(unlink(temp), add = TRUE)
 
   df <- data.frame(
     "d" = as.Date("2016-01-01") + -5:5,
@@ -907,10 +907,10 @@ test_that("numfmt in pivot tables works", {
                     filter = c("Location", "Status"), data = "Units")$
     add_pivot_table(df, dims = "A3", rows = "Plant",
                     filter = c("Location", "Status"), data = "Units",
-                    params = list(numfmt = c(formatCode = "#,###0"), sort_row = "ascending"))$
+                    params = list(numfmts = c(formatCode = "#,###0"), sort_row = "ascending"))$
     add_pivot_table(df, dims = "A3", rows = "Plant",
                     filter = c("Location", "Status"), data = "Units",
-                    params = list(numfmt = c(numfmt = 10), sort_row = "descending"))
+                    params = list(numfmts = c(numfmt = 10), sort_row = "descending"))
 
   exp <- c(
     "<dataField name=\"Sum of Units\" fld=\"3\" baseField=\"0\" baseItem=\"0\"/>",
@@ -953,8 +953,8 @@ test_that("numfmt in pivot tables works", {
   expect_error(
     wb$add_pivot_table(df, dims = "A3", rows = "cyl", cols = "gear",
                        data = c("vs", "am"),
-                       params = list(numfmt = c(numfmt = 10))),
-    "length of numfmt and data does not match"
+                       params = list(numfmts = c(numfmt = 10))),
+    "length of numfmts and data does not match"
   )
 
   ### add sortType only to those pivot fields that are sorted
@@ -1201,6 +1201,7 @@ test_that("adding mips section works", {
   expect_equal(fmips, wb$get_mips())
 
   tmp <- temp_xlsx()
+  on.exit(unlink(tmp), add = TRUE)
 
   wb$save(tmp)
 
@@ -1247,6 +1248,8 @@ test_that("adding mips section works", {
 
 test_that("handling mips in docMetadata works", {
   tmp <- temp_xlsx()
+  on.exit(unlink(tmp), add = TRUE)
+
   xml <- '<clbl:labelList xmlns:clbl=\"http://schemas.microsoft.com/office/2020/mipLabelMetadata\"><clbl:label foo="bar"/></clbl:labelList>'
   wb <- wb_workbook()$add_worksheet()$add_mips(xml = xml)
   wb$docMetadata
@@ -1298,3 +1301,197 @@ test_that("using and removing secondary bookviews works", {
   )
 
 })
+
+test_that("finalize works", {
+  fl <- system.file("extdata", "openxlsx2_example.xlsx", package = "openxlsx2")
+  wb <- wb_load(file = fl)
+
+  tmpstr <- wb$tmpDir
+  expect_true(dir.exists(tmpstr))
+  rm(wb)
+  gc()
+  expect_false(dir.exists(tmpstr))
+})
+
+test_that("pivot tables with formulas work", {
+  wb <- wb_workbook()$add_worksheet()$add_data(x = mtcars)
+
+  df <- wb_data(wb, sheet = 1)
+
+  wb <- wb_add_pivot_table(
+      wb,
+      df,
+      dims = "A3",
+      cols = NULL,
+      rows = "vs",
+      # For this case, the formula must return a single value
+      data = c("disp", "cyl", "=cyl/disp" = "Field1", "=Field1 * _xlfn.MAX(am)" = "Rand"),
+      param = list(
+        numfmts = c(
+          formatCode = c("#,##0.0"),
+          formatCode = c("#,##0.0"),
+          formatCode = c("0.0%"),
+          formatCode = c("0.0%")
+        )
+      )
+    )
+
+  expect_true(grepl("_xlfn.MAX", wb$pivotDefinitions))
+
+})
+
+test_that("pivot tables downfill works", {
+  wb <- wb_workbook()$add_worksheet("Pivot Examples")$add_data(x = mtcars)
+  df <- wb_data(wb, sheet = 1)
+  wb$add_pivot_table(
+    df,
+    dims = "B2",
+    rows = c("cyl", "vs"),
+    data = "mpg",
+    param = list(compact = FALSE, downfill = TRUE)
+  )
+  expect_true(grepl("fillDownLabels", wb$pivotTables))
+})
+
+test_that("pivot tables downfill works", {
+  wb <- wb_workbook()$add_worksheet("Pivot Examples")$add_data(x = mtcars)
+  df <- wb_data(wb, sheet = 1)
+  wb$add_pivot_table(
+    df,
+    dims = "B2",
+    rows = c("cyl", "vs"),
+    data = "mpg",
+    param = list(compact = FALSE, downfill = TRUE)
+  )
+  expect_true(grepl("fillDownLabels", wb$pivotTables))
+})
+
+test_that("disabling subtotals works", {
+
+  wb <- wb_workbook()$add_worksheet()$add_data(x = mtcars)
+  pt <- wb_data(wb)
+
+  # so how am I supposed to order this?
+  wb$
+    add_pivot_table(
+      pt,
+      cols = c("am", "carb"),
+      data = "disp",
+      params = list(
+        subtotal_top = FALSE,
+        default_subtotal = FALSE,
+        rowGrandTotals = FALSE,
+        colGrandTotals = FALSE,
+        compact = FALSE,
+        compact_data = FALSE,
+        outline = FALSE
+      )
+    )
+
+  expect_true(grepl("subtotalTop=\"0\"", wb$pivotTables))
+  expect_true(grepl("defaultSubtotal=\"0\"", wb$pivotTables))
+
+})
+
+test_that("data caption works", {
+
+  wb <- wb_workbook()$add_worksheet("DataSheet")$add_data(x = mtcars)
+
+  df <- wb_data(wb, sheet = "DataSheet")
+
+  wb$add_pivot_table(
+    df,
+    dims = "A3",
+    rows = "cyl",
+    cols = "gear",
+    data = c("disp", "hp"),
+    params = list(
+      apply_alignment_formats    = TRUE,
+      apply_number_formats       = TRUE,
+      apply_border_formats       = TRUE,
+      apply_font_formats         = TRUE,
+      apply_pattern_formats      = TRUE,
+      apply_width_height_formats = TRUE,
+      auto_format_id             = 4099,
+      data_caption = "My Metrics",      # only in compact_data
+      row_header_caption = "Cylinders", # w/o compact_data = FALSE
+      col_header_caption = "Gears",     # w/o compact_data = FALSE
+      # compact_data = FALSE,
+      compact = FALSE
+    )
+  )
+
+  expect_true(grepl("applyAlignmentFormats=\"1\"", wb$pivotTables))
+  expect_true(grepl("applyNumberFormats=\"1\"", wb$pivotTables))
+  expect_true(grepl("applyBorderFormats=\"1\"", wb$pivotTables))
+  expect_true(grepl("applyFontFormats=\"1\"", wb$pivotTables))
+  expect_true(grepl("applyPatternFormats=\"1\"", wb$pivotTables))
+  expect_true(grepl("applyWidthHeightFormats=\"1\"", wb$pivotTables))
+  expect_true(grepl("autoFormatId=\"4099\"", wb$pivotTables))
+
+  expect_true(grepl("dataCaption=\"My Metrics\"", wb$pivotTables))
+  expect_true(grepl("rowHeaderCaption=\"Cylinders\"", wb$pivotTables))
+  expect_true(grepl("colHeaderCaption=\"Gears\"", wb$pivotTables))
+
+})
+
+test_that("data caption works", {
+
+  wb <- wb_workbook()$add_worksheet("DataSheet")$add_data(x = mtcars)
+
+  df <- wb_data(wb, sheet = "DataSheet")
+
+  wb$add_pivot_table(
+    df,
+    dims = "A3",
+    rows = "cyl",
+    cols = "gear",
+    data = c("disp", "hp"),
+    params = list(
+      indent = FALSE,
+      show_row_headers = FALSE,
+      show_col_headers = FALSE,
+      show_row_stripes = FALSE,
+      show_col_stripes = FALSE,
+      show_last_column = FALSE,
+      item_print_titles = FALSE,
+      multiple_field_filters = FALSE,
+      col_grand_totals = FALSE,
+      row_grand_totals = FALSE,
+      outline = FALSE,
+      outline_data = FALSE
+    )
+  )
+
+
+  expect_true(grepl("showRowHeaders=\"0\"", wb$pivotTables))
+  expect_true(grepl("showColHeaders=\"0\"", wb$pivotTables))
+  expect_true(grepl("showRowStripes=\"0\"", wb$pivotTables))
+  expect_true(grepl("showColStripes=\"0\"", wb$pivotTables))
+  expect_true(grepl("showLastColumn=\"0\"", wb$pivotTables))
+  expect_true(grepl("itemPrintTitles=\"0\"", wb$pivotTables))
+  expect_true(grepl("colGrandTotals=\"0\"", wb$pivotTables))
+  expect_true(grepl("rowGrandTotals=\"0\"", wb$pivotTables))
+
+})
+
+test_that("standardize warning works", {
+
+  wb <- wb_workbook()$add_worksheet("DataSheet")$add_data(x = mtcars)
+
+  df <- wb_data(wb, sheet = "DataSheet")
+
+  expect_warning(
+    wb$add_pivot_table(
+      df,
+      dims = "A3",
+      rows = "cyl",
+      cols = "gear",
+      data = c("disp", "hp"),
+      params = list(
+        numfmt = "#.0"
+      )
+    ),
+    "unused arguments"
+  )
+})
